(function (global, factory) {
  typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('vue')) :
  typeof define === 'function' && define.amd ? define(['exports', 'vue'], factory) :
  (global = global || self, factory(global.VueNotificationRenderless = {}, global.Vue));
}(this, function (exports, Vue) { 'use strict';

  Vue = Vue && Vue.hasOwnProperty('default') ? Vue['default'] : Vue;

  var Events = new Vue();

  function _defineProperty(obj, key, value) {
    if (key in obj) {
      Object.defineProperty(obj, key, {
        value: value,
        enumerable: true,
        configurable: true,
        writable: true
      });
    } else {
      obj[key] = value;
    }

    return obj;
  }

  function ownKeys(object, enumerableOnly) {
    var keys = Object.keys(object);

    if (Object.getOwnPropertySymbols) {
      var symbols = Object.getOwnPropertySymbols(object);
      if (enumerableOnly) symbols = symbols.filter(function (sym) {
        return Object.getOwnPropertyDescriptor(object, sym).enumerable;
      });
      keys.push.apply(keys, symbols);
    }

    return keys;
  }

  function _objectSpread2(target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i] != null ? arguments[i] : {};

      if (i % 2) {
        ownKeys(source, true).forEach(function (key) {
          _defineProperty(target, key, source[key]);
        });
      } else if (Object.getOwnPropertyDescriptors) {
        Object.defineProperties(target, Object.getOwnPropertyDescriptors(source));
      } else {
        ownKeys(source).forEach(function (key) {
          Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key));
        });
      }
    }

    return target;
  }

  var VueNotificationRenderless = {
    name: 'vue-notification-renderless',
    props: {
      reverse: {
        type: Boolean,
        "default": false
      }
    },
    data: function data() {
      return {
        items: []
      };
    },
    methods: {
      generateId: function generateId() {
        return Math.random().toString(36).substr(2);
      },
      addItem: function addItem(event) {
        var _this = this;

        var item = _objectSpread2({
          id: this.generateId(),
          duration: 4000,
          close: function close() {
            return _this.closeItem(item);
          }
        }, event);

        if (item.duration && item.duration > 0 || !item.duration) {
          item.timer = setTimeout(function () {
            return item.close(item);
          }, item.duration);
        }

        if (this.reverse) {
          this.items.unshift(item);
        } else {
          this.items.push(item);
        }
      },
      closeItem: function closeItem(item) {
        this.items.splice(this.items.indexOf(item), 1);
      }
    },
    mounted: function mounted() {
      Events.$on('notification', this.addItem);
    },
    beforeDestroy: function beforeDestroy() {
      Events.$off('notification', this.addItem);
    },
    render: function render() {
      return this.$scopedSlots["default"]({
        items: this.items,
        close: this.closeItem
      });
    }
  };

  var index = {
    install: function install(Vue) {
      var args = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      if (this.installed) {
        return;
      }

      this.installed = true;
      Vue.component(args.wrapper_name || VueNotificationRenderless.name, VueNotificationRenderless);

      Vue.prototype.$notification = function (data) {
        return Events.$emit('notification', data);
      };
    }
  };

  exports.default = index;

  Object.defineProperty(exports, '__esModule', { value: true });

}));
